@@ -23,7 +23,7 @@ use English                qw(-no_match_vars);
 use Carp                   qw(carp croak confess);
 use Cwd                    qw();
 
-our $VERSION     = '1.10';
+our $VERSION     = '1.11';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT_OK ] );
@@ -104,6 +104,7 @@ my $TT_VAR_MATCH = _tt_block '(\w+)';
 my $PKGBUILD_TEMPL = <<'END_TEMPL';
 # Contributor: [% packager %]
 # Generator  : CPANPLUS::Dist::Arch [% version %]
+
 pkgname='[% pkgname %]'
 pkgver='[% pkgver %]'
 pkgrel='[% pkgrel %]'
@@ -126,23 +127,28 @@ build() {
     PERL_MB_OPT="--installdirs vendor --destdir '$pkgdir'" \
     MODULEBUILDRC=/dev/null
 
-  { cd "$DIST_DIR" &&
+  cd "$DIST_DIR"
 [% IF is_makemaker -%]
-    $PERL Makefile.PL &&
-    make &&
-    [% IF skiptest %]#[% END %]make test &&
-    make install;
+  $PERL Makefile.PL
+  make
+  [% IF skiptest %]#[% END %]make test
+  make install
 [% END -%]
 [% IF is_modulebuild -%]
-    $PERL Build.PL &&
-    $PERL Build &&
-    [% IF skiptest %]#[% END %]$PERL Build test &&
-    $PERL Build install;
+  $PERL Build.PL
+  $PERL Build
+  [% IF skiptest %]#[% END %]$PERL Build test
+  $PERL Build install
 [% END -%]
-  } || return 1;
 
   find "$pkgdir" -name .packlist -o -name perllocal.pod -delete
 }
+
+# Local Variables:
+# mode: shell-script
+# sh-basic-offset: 2
+# End:
+# vim:set ts=2 sw=2 et:
 END_TEMPL
 
 =for Weird "perl Build" Syntax
@@ -250,7 +256,7 @@ sub init
 
     $self->status->mk_accessors( qw{ pkgname  pkgver  pkgbase pkgdesc
                                      pkgurl   pkgsize arch    pkgrel
-                                     builddir destdir cfgdeps
+                                     builddir destdir metadeps
 
                                      pkgbuild_templ tt_init_args } );
 
@@ -832,6 +838,16 @@ sub _extract_makedepends
     return \%makedeps;
 }
 
+#---HELPER FUNCTION---
+# Converts a decimal perl version (like $]) into the dotted decimal
+# form that the official ArchLinux perl package uses.
+sub _translate_perl_ver
+{
+    my ($perlver) = @_;
+    return $perlver unless $perlver =~ / \A (\d+) [.] (\d{3}) (\d{3}) \z /xms;
+    return sprintf '%d.%d.%d', $1, $2, $3;
+}
+
 #---PRIVATE METHOD---
 # Translates CPAN module dependencies into ArchLinux package dependencies.
 sub _translate_cpan_deps
@@ -849,7 +865,7 @@ sub _translate_cpan_deps
 
         # Sometimes a perl version is given as a prerequisite
         if ( $modname eq 'perl' ) {
-            $pkgdeps{perl} = $depver;
+            $pkgdeps{perl} = _translate_perl_ver( $depver );
             next CPAN_DEP_LOOP;
         }
 
@@ -910,13 +926,25 @@ sub _get_pkg_deps
     my $backend = $module->parent;
     my $prereqs = $module->status->prereqs;
 
-    my $pkgdeps_ref  = $self->_translate_cpan_deps( $prereqs );
-    my $makedeps_ref = $self->_extract_makedepends( $pkgdeps_ref );
-    my $cfgdeps_ref  = $self->_translate_cpan_deps( $self->status->cfgdeps );
+    # Take our CPAN and META.yml dependencies (of distribution names) and
+    # convert them into packages names for 'depends' and 'makedepends'
+    # inside of a PKGBUILD.
+
+    my $pkgdeps_ref   = $self->_translate_cpan_deps( $prereqs );
+    my $makedeps_ref  = $self->_extract_makedepends( $pkgdeps_ref );
+    my $cfgdeps_ref   = $self->_translate_cpan_deps
+        ( $self->status->metadeps->{'cfg'} );
+    my $builddeps_ref = $self->_translate_cpan_deps
+        ( $self->status->metadeps->{'build'} );
+
+    # 'configure_requires' from META.yml don't show in the prereqs()
+    # results but I think 'build_requires' do
+    for ( keys %$builddeps_ref ) { delete $pkgdeps_ref->{ $_ }; }
     _merge_deps( $makedeps_ref, $cfgdeps_ref );
+    _merge_deps( $makedeps_ref, $builddeps_ref );
 
     # Merge in the XS C library package deps...
-    my $xs_deps      = $self->_translate_xs_deps;
+    my $xs_deps = $self->_translate_xs_deps;
     _merge_deps( $pkgdeps_ref, $xs_deps );
     
     # Require perl unless we have a dependency on a perl module or perl
@@ -925,38 +953,6 @@ sub _get_pkg_deps
     return { 'depends' => $pkgdeps_ref, 'makedepends' => $makedeps_ref };
 }
 
-#---HELPER FUNCTION---
-sub _metayml_pkgdesc
-{
-    my ($mod_obj) = @_;
-    my $metayml;
-
-    unless ( open $metayml, '<',
-             catfile( $mod_obj->status->extract, 'META.yml' )) {
-        _DEBUG( "Could not open META.yml to get pkgdesc: $!" );
-        return undef;
-    }
-
-    while ( <$metayml> ) {
-        chomp;
-        if ( my ($pkgdesc) = / \A abstract: \s* (.+) \s* \z /xms ) {
-            _DEBUG qq{Found pkgdesc "$pkgdesc" in META.yml};
-
-            # Ignore enclosing quotes...
-            $pkgdesc = $2 if ( $pkgdesc =~ / \A (['"]) (.*) \1 \z /xms );
-
-            # Ignore certain values we don't like...
-            for my $bad ( @BAD_METAYML_ABSTRACTS ) {
-                return undef if $pkgdesc eq $bad;
-            }
-
-            return $pkgdesc;
-        }
-    }
-
-    return undef;
-}
-
 #---HELPER FUNCTION---
 sub _pod_pkgdesc
 {
@@ -1117,16 +1113,15 @@ sub _prepare_pkgdesc
 
     my @pkgdesc_srcs =
         (
-         # Registered modules have their description stored in the object.
+         # 1. We checked the META.yml earlier in the _scan_metayml method.
+
+         # 2. Registered modules have their description stored in the object.
          sub { $module->description },
 
-         # First, try to find the short description in the META.yml file...
-         \&_metayml_pkgdesc,
-          
-         # Next, parse the source file or pod file for a NAME section...
+         # 3. Parse the source file or pod file for a NAME section.
          \&_pod_pkgdesc,
 
-         # Last, try to find it in in the README file...
+         # 4. Try to find it in in the README file.
          \&_readme_pkgdesc,
 
          );
@@ -1139,20 +1134,32 @@ sub _prepare_pkgdesc
     return $status->pkgdesc( $pkgdesc || q{} );
 }
 
-sub _prepare_cfgdeps
+#--- PRIVATE METHOD ---
+# We read the META.yml file with Parse::CPAN::META and extract
+# data needed for makedepends and pkgdesc if we can.
+sub _scan_metayml
 {
     my ($self) = @_;
     my ($status, $modobj) = ($self->status, $self->parent);
 
-    $status->cfgdeps( {} ); # Default to an empty list of deps
+    # Default to an empty list of deps
+    $status->metadeps( { 'cfg' => {}, 'build' => {} } );
 
     my $metapath = catfile( $modobj->status->extract, 'META.yml' );
     return unless -f $metapath;
     
-    my $meta_ref = Parse::CPAN::Meta::LoadFile( $metapath );
-    return unless $meta_ref->{'configure_requires'};
+    my $meta_ref = eval { Parse::CPAN::Meta::LoadFile( $metapath ) }
+        or return;
+
+    $status->metadeps->{'cfg'}   = $meta_ref->{'configure_requires'};
+    $status->metadeps->{'build'} = $meta_ref->{'build_requires'};
+
+    my $pkgdesc = $meta_ref->{'abstract'} or return;
+    for my $baddesc ( @BAD_METAYML_ABSTRACTS ) {
+        return if $pkgdesc eq $baddesc;
+    }
     
-    $status->cfgdeps( $meta_ref->{'configure_requires'} );
+    $status->pkgdesc( $pkgdesc );
     return;
 }
 
@@ -1198,8 +1205,10 @@ sub _prepare_status
     $status->tt_init_args( {} );
 
     $self->_prepare_arch();
-    $self->_prepare_pkgdesc();
-    $self->_prepare_cfgdeps();
+    $self->_scan_metayml();
+
+    # _scan_metayml() might find a pkgdesc for us
+    $self->_prepare_pkgdesc() unless $status->pkgdesc();
 
     return $status;
 }
